@@ -1,7 +1,7 @@
 """Provides access to config variables."""
 
 import os
-from typing import Optional, List, Dict
+from typing import Optional, List, Dict, Any
 
 import toml
 from frozendict import frozendict
@@ -155,6 +155,9 @@ def read_configs(config_paths: List[str]) -> frozendict:
     reference_base = "gs://cpg-reference"
     deployment_name = "cpg"
 
+    [CPG_DEPLOY_CONFIG.datasets.tob-wgs]
+    projectId = "tob-wgs"
+    
     >>> from cpg_utils.config import get_config
     >>> get_config()['workflow']['dataset']
     'tob-wgs'
@@ -180,3 +183,27 @@ def update_dict(d1: Dict, d2: Dict) -> None:
             update_dict(v1, v2)
         else:
             d1[k] = v2
+
+
+class ConfigError(Exception):
+    """
+    Error retrieving keys from config.
+    """
+
+
+def retrieve(key: list[str] | str, default: Any | None = None) -> str:
+    """
+    Retrieve key from config, assuming nested key specified as a list of strings.
+    """
+    if isinstance(key, str):
+        key = [key]
+
+    d = get_config()
+    for k in key[:-1]:
+        if k not in d:
+            raise ConfigError(f'Key "{k}" not found in {d}')
+        d = d[k]
+    k = key[-1]
+    if k not in d and not default:
+        raise ConfigError(f'Key "{k}" not found in {d}')
+    return d.get(k, default)
