@@ -5,7 +5,8 @@ import google.auth
 import google.auth.exceptions
 import google.auth.transport.requests
 import pytest
-from cpg_utils.auth import get_sample_metadata_token, get_user_from_headers
+from cpg_utils.auth import get_user_from_headers
+from cpg_utils.creds import get_sample_metadata_token
 from cpg_utils.deploy_config import set_deploy_config_from_env
 from google.oauth2 import service_account
 
@@ -73,12 +74,14 @@ def mock_get_default_creds():
 
 def test_az_default_token(monkeypatch):
     monkeypatch.setenv("CLOUD", "azure")
+    monkeypatch.delenv("CPG_DEPLOY_CONFIG", raising=False)
     monkeypatch.setattr(azure.identity, "DefaultAzureCredential", mock_get_creds)
     set_deploy_config_from_env()
     assert get_sample_metadata_token() == "creds"
 
 
 def test_az_file_token(monkeypatch, test_resources_path):
+    monkeypatch.delenv("CPG_DEPLOY_CONFIG", raising=False)
     monkeypatch.setenv("CLOUD", "azure")
     set_deploy_config_from_env()
     monkeypatch.setattr(azure.identity, "ClientSecretCredential", mock_get_creds)
@@ -94,6 +97,7 @@ def test_gcp_default_token(monkeypatch):
 
 
 def test_gcp_file_token(monkeypatch, test_resources_path):
+    monkeypatch.delenv("CPG_DEPLOY_CONFIG", raising=False)
     monkeypatch.setenv("CLOUD", "gcp")
     set_deploy_config_from_env()
     monkeypatch.setattr(service_account.IDTokenCredentials, "from_service_account_info", mock_get_creds)
